.. _porting_guides:

**********************
Ansible Porting Guides
**********************

This section lists porting guides that can help you in updating playbooks, plugins and other parts of your Ansible infrastructure from one version of Ansible to the next.

.. toctree::
   :maxdepth: 1
   :glob:

   porting_guide_4
   porting_guide_3
   porting_guide_2.10
   porting_guide_2.9
   porting_guide_2.8
   porting_guide_2.7
   porting_guide_2.6
   porting_guide_2.5
   porting_guide_2.4
   porting_guide_2.3
   porting_guide_2.0
